module.exports = defineTest({
	description: 'Assignments to global variables should be effects (#1587)'
});
